#!/bin/bash
# Fast Site Engine. Copyright © AC (acwed@ya.ru), 2004-2024. All rights reserved. 2-clause BSD license.
# https://fsen.ru/linux/games
# l=/tmp/games.sh;rm -f $l;wget -qP /tmp https://fsen.ru/inc/doc/linux/games.sh;chmod +x $l;$l

#-----------------------------------------------------------------------
# Получаем переданные скрипту аргументы
#-----------------------------------------------------------------------
PORTPROTON=${1-~/} # Директория PortProton
LUTRIS=${2-~/} # Директория Lutris
PROGS=${3-full} # Список программ
ist(){
  local N=${1-}
  [[ "$PROGS" == 'full'  || "$PROGS" =~ "$N" ]] && echo 1 || echo 0
}

#-----------------------------------------------------------------------
# Подключаем репозитории
#-----------------------------------------------------------------------
if (($(ist 'mangohud'))); then sudo add-apt-repository -y ppa:flexiondotorg/mangohud; fi
if (($(ist 'portproton'))); then sudo add-apt-repository -y multiverse; fi
if (($(ist 'lutris'))); then sudo add-apt-repository -y ppa:lutris-team/lutris; fi
if (($(ist 'portproton') || $(ist 'winehq'))); then
  # Включим 32-битную архитектуру
  sudo dpkg --add-architecture i386
fi
if (($(ist 'winehq'))); then
  # Загрузим ключ репозитория Wine
  wget -qP /tmp https://dl.winehq.org/wine-builds/winehq.key
  # Добавляем ключ репозитория в систему
  sudo apt-key add /tmp/winehq.key
  # Добавляем репозиторий Wine
  S='DISTRIB_CODENAME=';N=$(cat /etc/*release | grep $S);N=${N//$S};sudo apt-add-repository -y 'deb https://dl.winehq.org/wine-builds/ubuntu/ '$N' main'
fi

#-----------------------------------------------------------------------
# Обновляем систему
#-----------------------------------------------------------------------
sudo apt update
sudo apt upgrade -y

#-----------------------------------------------------------------------
# Устанавливаем WineHQ - транслятор Windows вызовов в Linux
#-----------------------------------------------------------------------
if (($(ist 'winehq'))); then
  sudo apt install -y aria2 # Для загрузки файлов
  # Установливаем WineHQ
  sudo apt install -y --install-recommends winehq-stable
  # Утилита для настройки WineHQ
  sudo apt install -y winetricks
fi

#-----------------------------------------------------------------------
# GameMode - набор оптимизаций, временно применяемых к хосту и/или игровому процессу
#-----------------------------------------------------------------------
if (($(ist 'gamemode'))); then sudo apt install -y gamemode; fi
# gamemoded -s
# gamemode is inactive || is active

#-----------------------------------------------------------------------
# MangoHUD - вывод FPS, температуры итд.
#-----------------------------------------------------------------------
#sudo add-apt-repository -y ppa:flexiondotorg/mangohud
#sudo apt update
if (($(ist 'mangohud'))); then sudo apt install -y mangohud; fi
# sudo apt remove -y mangohud mangohud:i386

# Утилита для наложения различных эффектов на Vulkan API (аналог ReShade Windows)
if (($(ist 'vkbasalt'))); then sudo apt install -y vkbasalt; fi

# Утилита для настройки mangohud и vkbasalt
if (($(ist 'goverlay'))); then sudo apt install -y goverlay; fi

#-----------------------------------------------------------------------
# Игровой клиент Steam
#-----------------------------------------------------------------------
if (($(ist 'steam'))); then sudo apt install -y steam; fi

#-----------------------------------------------------------------------
# Менеджер видеоигр Lutris
#-----------------------------------------------------------------------
#sudo add-apt-repository -y ppa:lutris-team/lutris
#sudo apt update
if (($(ist 'lutris'))); then
  if [[ $LUTRIS != '~/' ]]; then
    LUTRIS=${LUTRIS/~\//\/home\/$USER\/}
    mkdir -p $LUTRIS'lutris/.cache/lutris'
    mkdir -p $LUTRIS'lutris/.config/lutris'
    mkdir -p $LUTRIS'lutris/.local/share/lutris'
    ln -s $LUTRIS'lutris/.cache/lutris' ~/.cache/lutris
    ln -s $LUTRIS'lutris/.config/lutris' ~/.config/lutris
    ln -s $LUTRIS'lutris/.local/share/lutris' ~/.local/share/lutris
  fi
  sudo apt install -y lutris
fi

#sudo apt install -y plasma5-xdg-desktop-portal-kde  fix VK Play

#-----------------------------------------------------------------------
# PortProton - позволяет запускать игры Steam, Orign и прочих, без использования этих клиентов. https://linux-gaming.ru/2022/11/24/portproton/
#-----------------------------------------------------------------------
if (($(ist 'portproton'))); then
  if [[ $PORTPROTON != '~/' ]]; then
    PORTPROTON=${PORTPROTON/~\//\/home\/$USER\/}
    mkdir $PORTPROTON'PortProton/'
    ln -s $PORTPROTON'PortProton/' ~/PortProton
  fi

  wget -qO /tmp/portproton_1.4-1_amd64.deb -P /tmp --show-progress https://github.com/Castro-Fidel/PortProton_dpkg/releases/download/portproton_1.4-1_amd64/portproton_1.4-1_amd64.deb
  sudo dpkg -i /tmp/*.deb
  sudo apt install -f -y
  rm -vf /tmp/portproton_1.4-1_amd64.deb

    ## sudo dpkg --add-architecture i386
    #sudo add-apt-repository -y multiverse
    #sudo apt update
    #sudo apt upgrade -y
  #sudo apt install -y wget
  #sudo apt install -y curl
  #sudo apt install -y file
  #sudo apt install -y libc6
  #sudo apt install -y libnss3
  #sudo apt install -y policykit-1
  #sudo apt install -y xz-utils
  #sudo apt install -y zenity
  #sudo apt install -y bubblewrap
  #sudo apt install -y icoutils
  #sudo apt install -y tar
  #sudo apt install -y libvulkan1
  #sudo apt install -y libvulkan1:i386
  #sudo apt install -y zenity
  #sudo apt install -y zstd
  #sudo apt install -y cabextract
  #sudo apt install -y xdg-utils
  #sudo apt install -y openssl
  #sudo apt install -y bc
  #sudo apt install -y libgl1-mesa-glx
  #sudo apt install -y libgl1-mesa-glx:i386

    #wget -qP /tmp 'https://github.com/Castro-Fidel/PortWINE/raw/master/portwine_install_script/PortProton_1.0'
    #chmod +x /tmp/PortProton_1.0
    #/tmp/PortProton_1.0 -rus
  #wget -qP /tmp 'https://github.com/Castro-Fidel/PortProton_ALT/raw/main/portproton'
  #chmod +x /tmp/portproton
  #/tmp/portproton -rus
fi

echo '------------------------------------------------------------------------------------------------------'
echo '--------------------------------------- УСТАНОВКА ЗАВЕРШЕНА! -----------------------------------------'
echo '------------------------------------------------------------------------------------------------------'