#!/bin/bash
# Fast Site Engine. Copyright © AC (acwed@ya.ru), 2004-2024. All rights reserved. 2-clause BSD license.
# Установщик и настройщик программ и оболочки для KDE Neon User Edition (основан на Ubuntu 22.04 LTS (Jammy Jellyfish) окончание поддержки 04.2027)
# https://fsen.ru/linux/programs  DISTR='jammy'
# rm -f /tmp/setup.sh && wget --no-check-certificate -qP /tmp https://fsen.ru/inc/doc/linux/setup.sh && chmod +x /tmp/setup.sh && /tmp/setup.sh

# Кнопки Пуска: отключения и перезагрузки не работают только под virtualbox

#-----------------------------------------------------------------------
# Ссылки за которыми требуется следить
#-----------------------------------------------------------------------
NBLNK='https://dlcdn.apache.org/netbeans/netbeans-installers/21/apache-netbeans_21-1_all.deb'
YALNK='https://cachev2-spbmiran-03.cdn.yandex.net/download.cdn.yandex.net/browser/yandex/24_1_1_940_54214/Yandex.deb'
# games PortProton

#-----------------------------------------------------------------------
# Получаем переданные скрипту аргументы
#-----------------------------------------------------------------------
export VOLUME=${1-88} # Громкость звука при запуске ОС (в процентах %)
DIR=${2-~/} # Быстрый доступ к директории (значок возле пуска)  '/home/'$USER'/'
NOTES=${3-~/notes.txt} # Быстрый доступ к блокноту Geany (значок возле пуска), настоятельно рекомендую хранить на диске с данными '/media/'$USER'/sdb?/notes.txt'
SCR=${4-/tmp/0.png} # Куда сохранять снимки экрана для открытия в Krita
export PROGS=${5-full} # Список программ (export чтоб ist() видела переменную в вызываемых скриптах.)
ist(){
  local N=${1-}
  [[ "$PROGS" == 'full'  || "$PROGS" =~ "$N" ]] && echo 1 || echo 0
}
export -f ist

#-----------------------------------------------------------------------
# Заменить пути на абсолютные path=’readlink -f “${BASH_SOURCE:-$0}”’
#-----------------------------------------------------------------------
DIR=${DIR/~\//\/home\/$USER\/}
NOTES=${NOTES/~\//\/home\/$USER\/}
SCR=${SCR/~\//\/home\/$USER\/}

#-----------------------------------------------------------------------
# Определяем индексы в концигурации
#-----------------------------------------------------------------------
export PANEL=2 #                                                 plugin=org.kde.panel
export SYSTEMTRAY=7 # В Kubuntu = 8                                     org.kde.plasma.private.systemtray
for ((I=0; I<10; I++)); do
  V=$(kreadconfig5 --file plasma-org.kde.plasma.desktop-appletsrc --group Containments --group $I --key plugin)
  if [[ $V == 'org.kde.panel' ]]; then PANEL=$I
  elif [[ $V =~ 'systemtray' ]]; then SYSTEMTRAY=$I
  fi
done
# default: 3;4;5;6;7;20;21
export PKICKOFF=3       #  3 - kickoff (пуск)                           org.kde.plasma.kickoff
export PAGER=4          #  4 - pager (переключение столов)              org.kde.plasma.pager
export PTASK=5          #  5 - icontasks (панель задач только значки)   org.kde.plasma.icontasks //org.kde.plasma.taskmanager
export PSEPARATOR=0     #  6 - marginsseparator (разделитель)           org.kde.plasma.marginsseparator //может не быть
export PSYSTEMTRAY=7    #  7 - systemtray (системный лоток)             org.kde.plasma.systemtray // В Kubuntu 6
export PDIGITALCLOCK=20 # 20 - digitalclock (цифровые часы)             org.kde.plasma.digitalclock // В Kubuntu 8
export PSHOWDESKTOP=21  # 21 - showdesktop (свернуть окна)              org.kde.plasma.showdesktop // В Kubuntu 9 org.kde.plasma.minimizeall
export PHINDEX=21 # [Containments][2(PANEL)][Applets][21] старший занятый индекс
for ((I=0; I<40; I++)); do
  V=$(kreadconfig5 --file plasma-org.kde.plasma.desktop-appletsrc --group Containments --group $PANEL --group Applets --group $I --key plugin)
  if [ -n "$V" ]; then
    PHINDEX=$I
    if [[ $V =~ 'kickoff' ]]; then PKICKOFF=$I
    elif [[ $V =~ 'pager' ]]; then PAGER=$I
    elif [[ $V =~ 'task' ]]; then PTASK=$I
    elif [[ $V =~ 'separator' ]]; then PSEPARATOR=$I
    elif [[ $V =~ 'systemtray' ]]; then PSYSTEMTRAY=$I
    elif [[ $V =~ 'digitalclock' ]]; then PDIGITALCLOCK=$I
    elif [[ $V =~ 'showdesktop' || $V =~ 'minimizeall' ]]; then PSHOWDESKTOP=$I
    fi
  fi
done

#-----------------------------------------------------------------------
# Отключить бумажник KDE временно..
#-----------------------------------------------------------------------
kwriteconfig5 --file kwalletrc --group Wallet --key Enabled --type bool false

#-----------------------------------------------------------------------
# Для загрузки файлов (обычно уже есть в системе)
#-----------------------------------------------------------------------
sudo apt install -y wget
sudo apt install -y curl
# sudo apt install -y apt-transport-https # Поддержка https была перенесена в пакет apt с версии 1.5

#-----------------------------------------------------------------------
# Настраиваем систему
#-----------------------------------------------------------------------
rm -f /tmp/tune.sh && wget -qP /tmp https://fsen.ru/inc/doc/linux/tune.sh && chmod +x /tmp/tune.sh && /tmp/tune.sh # $VOLUME $DIR $NOTES $SCR == export

#-----------------------------------------------------------------------
# Добавление репозиториев PPA /etc/apt/
#-----------------------------------------------------------------------
if (($(ist 'librewolf'))); then # Браузер LibreWolf - на базе движка Firefox
  wget -O- https://deb.librewolf.net/keyring.gpg | sudo gpg --dearmor -o /usr/share/keyrings/librewolf.gpg
  S='DISTRIB_CODENAME=';N=$(cat /etc/*release | grep $S);N=${N//$S};
  echo -e 'Types: deb\nURIs: https://deb.librewolf.net\nSuites: '$N'\nComponents: main\nArchitectures: amd64\nSigned-By: /usr/share/keyrings/librewolf.gpg' | sudo tee /etc/apt/sources.list.d/librewolf.sources > /dev/null
fi

#-----------------------------------------------------------------------
# Обновляем списки программ и систему
#-----------------------------------------------------------------------
sudo apt update
sudo apt upgrade -y

#-----------------------------------------------------------------------
# Устанавливаю SRWare Iron зарнее, чтоб сразу прожать лицензию, скачивая deb пакет
#-----------------------------------------------------------------------
if (($(ist 'iron'))); then wget -qP /tmp --show-progress https://www.srware.net/downloads/iron64.deb; fi
sudo dpkg -i /tmp/*.deb
sudo apt install -f -y
rm -vf /tmp/iron64.deb

#-----------------------------------------------------------------------
# Устанавливаем программы из репозитория                                # Если всё вместе писать install -y gufw gparted ... - обрывает всю установку при проблеме с пакетом
#-----------------------------------------------------------------------
##sudo apt install -y qdbus # kdeup.sh
sudo apt install -y gconf2 # mailspring uses
# Для md
sudo apt install -y bc
# sudo apt install -y curl
sudo apt install -y gdisk
sudo apt install -y util-linux
sudo apt install -y smartmontools
l=/usr/bin/md;sudo rm -f $l;sudo wget -qP /usr/bin https://fsen.ru/inc/doc/linux/md;sudo chmod +x $l

l=ttf-mscorefonts-installer; if (($(ist "$l"))); then sudo apt install -y $l; fi
l=kubuntu-restricted-extras; if (($(ist "$l"))); then sudo apt install -y $l; fi
l=fonts-open-sans; if (($(ist "$l"))); then sudo apt install -y $l; fi # Для Telegram
l=oxygen-icon-theme; if (($(ist "$l"))); then sudo apt install -y $l; fi
l=adwaita-icon-theme-full; if (($(ist "$l"))); then sudo apt install -y $l; fi
# sudo apt install -y adwaita-icon-theme   # Конфликт с neon-adwaita (full пакет справляется - магия)

l=bleachbit; if (($(ist "$l"))); then sudo apt install -y $l; fi
l=gufw; if (($(ist "$l"))); then sudo apt install -y $l; fi # Присутствует по умолчанию, оставлено для других сборок
l=xvkbd; if (($(ist "$l"))); then sudo apt install -y $l; fi
l=xbindkeys; if (($(ist "$l"))); then sudo apt install -y $l; fi
l=xbindkeys-config; if (($(ist "$l"))); then sudo apt install -y $l; fi
l=pwgen; if (($(ist "$l"))); then sudo apt install -y $l; fi
l=traceroute; if (($(ist "$l"))); then sudo apt install -y $l; fi
l=gsmartcontrol; if (($(ist "$l"))); then sudo apt install -y $l; fi
l=xarchiver; if (($(ist "$l"))); then sudo apt install -y $l; fi
l=k3b; if (($(ist "$l"))); then sudo apt install -y $l; fi
l=kcalc; if (($(ist "$l"))); then sudo apt install -y $l; fi
l=partitionmanager; if (($(ist "$l"))); then sudo apt install -y $l; fi
if (($(ist "muon"))); then # Пакетный менеджер, отсутсвует по умолчанию в KDE Neon
  sudo apt install -y muon
  # software-properties-kde нет такого пакета, поставим другой и создадим ссылку
  sudo apt install -y software-properties-qt
  sudo ln -s /usr/bin/software-properties-qt /usr/bin/software-properties-kde
fi
# Сканирование изображений
l=skanlite; if (($(ist "$l"))); then sudo apt install -y $l; fi
#sudo apt install -y xsane
#sudo apt install -y skanimage
#-----------------------------------------------------------------------
if (($(ist 'easyeffects'))); then
  sudo apt install -y flatpak
  flatpak remote-add --if-not-exists flathub https://flathub.org/repo/flathub.flatpakrepo
  flatpak install -y flathub com.github.wwmm.easyeffects
fi
# sudo apt install -y gnome-software-plugin-flatpak
# flatpak install -y flathub org.gnome.Geary
# flatpak run org.gnome.Geary

# flatpak update   https://docs.flatpak.org/ru/latest/using-flatpak.html
# flatpak list
# flatpak list --app
# flatpak uninstall -y org.gnome.Geary
# flatpak uninstall -y --unused
# apt list --installed
#-----------------------------------------------------------------------
l=qasmixer; if (($(ist "$l"))); then sudo apt install -y $l; fi
l=audacious; if (($(ist "$l"))); then sudo apt install -y $l; fi

l=tuxguitar; if (($(ist "$l"))); then sudo apt install -y $l; fi
l=lingot; if (($(ist "$l"))); then sudo apt install -y $l; fi

l=smplayer; if (($(ist "$l"))); then sudo apt install -y $l; fi
l=smplayer-themes; if (($(ist "$l"))); then sudo apt install -y $l; fi
# sudo apt install -y smplayer-skins
l=guvcview; if (($(ist "$l"))); then sudo apt install -y $l; fi
# zoom .deb ниже
# skype .deb ниже

# mailspring .deb ниже
# telegram .tar.xz ниже
# discord .deb ниже


l=ffmpeg; if (($(ist "$l"))); then sudo apt install -y $l; fi
#sudo add-apt-repository -y ppa:obsproject/obs-studio
#sudo apt update
l=obs-studio; if (($(ist "$l"))); then sudo apt install -y $l; fi
l=shotcut; if (($(ist "$l"))); then sudo apt install -y $l; fi

# remove-firefox ниже
# iron .deb выше
l=librewolf; if (($(ist "$l"))); then sudo apt install -y $l; fi
l=falkon; if (($(ist "$l"))); then sudo apt install -y $l; fi
# yandex .deb ниже

l=scrot; if (($(ist "$l"))); then sudo apt install -y $l; fi
l=krita; if (($(ist "$l"))); then sudo apt install -y $l; fi
l=krita-l10n; if (($(ist "$l"))); then sudo apt install -y $l; fi # Уже установлен, на всякий случай оставляю для других сборок
# sudo apt install -y gimp
# sudo apt install -y gimp-plugin-registry

l=ktorrent; if (($(ist "$l"))); then sudo apt install -y $l; fi
l=eiskaltdcpp-qt; if (($(ist "$l"))); then sudo apt install -y $l; fi
l=filezilla; if (($(ist "$l"))); then sudo apt install -y $l; fi

l=catfish; if (($(ist "$l"))); then sudo apt install -y $l; fi
l=qdirstat; if (($(ist "$l"))); then sudo apt install -y $l; fi
l=kdiff3; if (($(ist "$l"))); then sudo apt install -y $l; fi
l=regexxer; if (($(ist "$l"))); then sudo apt install -y $l; fi

l=geany; if (($(ist "$l"))); then sudo apt install -y $l; fi
# netbeans .deb ниже

if (($(ist 'libreoffice'))); then
  sudo apt install -y --no-install-recommends libreoffice-writer libreoffice-calc libreoffice-l10n-ru # libreoffice-gtk3
  sudo apt install -y hunspell-ru # Словарь для проверки орфографии LibreOffice
  # sudo apt install -y mythes-ru # Словарь синонимов для LibreOffice
  # Решаем проблему с мелким шрифтом в меню
  sudo apt purge -y libreoffice-gtk2 libreoffice-gtk
  sudo apt install -y libreoffice-gtk3
fi

#-----------------------------------------------------------------------
# Устанавливаем Telegram (скачиваем архив и распаковываем)
#-----------------------------------------------------------------------
if (($(ist 'telegram'))); then
  wget -qO /tmp/telegram.tar.xz -P /tmp --show-progress https://telegram.org/dl/desktop/linux
  tar -xf /tmp/telegram.tar.xz -C ~/.local/share/
  # Сам добавит значок в меню Интернет при запуске
  nohup /home/$USER/.local/share/Telegram/Telegram -workdir /home/$USER/.local/share/TelegramDesktop/ &
  sleep 10
  killall -15 Telegram
  sleep 5
  rm -vf /tmp/telegram.tar.xz
fi

#-----------------------------------------------------------------------
# Устанавливаем программы скачивая deb пакеты                           # cd /tmp -> -P /tmp
#-----------------------------------------------------------------------
if (($(ist 'zoom'))); then
  #sudo apt install -y ibus
  #sudo apt install -y libxcb-xtest0
  #sudo apt install -y libegl1-mesa
  #sudo apt install -y libgl1-mesa-glx
  wget -qP /tmp --show-progress https://zoom.us/client/latest/zoom_amd64.deb
fi
if (($(ist 'skype'))); then wget -qP /tmp --show-progress https://repo.skype.com/latest/skypeforlinux-64.deb; fi

if (($(ist 'mailspring'))); then wget -qO /tmp/mailspring.deb -P /tmp --show-progress https://updates.getmailspring.com/download?platform=linuxDeb; fi
if (($(ist 'discord'))); then wget -qO /tmp/discord.deb -P /tmp --show-progress https://discord.com/api/download?platform=linux&format=deb; fi

if (($(ist 'yandex'))); then wget -qP /tmp --show-progress $YALNK; fi

if (($(ist 'netbeans'))); then
  sudo apt install -y default-jdk
  wget -qO /tmp/netbeans.deb -P /tmp --show-progress $NBLNK
fi
sudo dpkg -i /tmp/*.deb
sudo apt install -f -y

rm -vf /tmp/zoom_amd64.deb /tmp/skypeforlinux-64.deb /tmp/mailspring.deb /tmp/discord.deb /tmp/Yandex.deb /tmp/netbeans.deb

# Tor Browser
#wget -qP /tmp https://www.torproject.org/dist/torbrowser/10.0.17/tor-browser-linux64-10.0.17_ru.tar.xz
#tar -xf /tmp/tor-browser-linux64-*_ru.tar.xz -C ~/.local/share/
   ### tar -xvJf /tmp/tor-browser-linux64-*_ru.tar.xz -C ~/.local/share/
#echo '[Desktop Entry]\nType=Application\nName=Tor Browser\nGenericName=Web Browser\nComment=Tor Browser is +1 for privacy and −1 for mass surveillance\nCategories=Network;WebBrowser;Security;\nExec=sh -c '\''"/home/ac/.local/share/tor-browser_ru/Browser/start-tor-browser" --detach || ([ !  -x "/home/ac/.local/share/tor-browser_ru/Browser/start-tor-browser" ] && "$(dirname "$*")"/Browser/start-tor-browser --detach)'\'' dummy %k\nX-TorBrowser-ExecShell=/home/ac/.local/share/tor-browser_ru/Browser/start-tor-browser --detach\nIcon=/home/'$USER'/.local/share/tor-browser_ru/Browser/browser/chrome/icons/default/default128.png\nStartupWMClass=Tor Browser' > ~/.local/share/applications/torbrowser.desktop && sudo chmod +x ~/.local/share/applications/torbrowser.desktop


#-----------------------------------------------------------------------
# На случай непредвиденных ошибок при установке, бывает "плавают" пакеты
sudo apt --fix-broken install -y
#-----------------------------------------------------------------------

#-----------------------------------------------------------------------
# Настраиваем браузер SRWare Iron
#-----------------------------------------------------------------------
if (($(ist 'iron'))); then rm -f /tmp/iron.sh && wget -qP /tmp https://fsen.ru/inc/doc/linux/iron.sh && chmod +x /tmp/iron.sh && /tmp/iron.sh; fi

#-----------------------------------------------------------------------
# Настраиваем браузер LibreWolf
#-----------------------------------------------------------------------
if (($(ist 'librewolf'))); then rm -f /tmp/librewolf.sh && wget -qP /tmp https://fsen.ru/inc/doc/linux/librewolf.sh && chmod +x /tmp/librewolf.sh && /tmp/librewolf.sh; fi

#-----------------------------------------------------------------------
# Отключаем кэширование на диск yandex-browser
#-----------------------------------------------------------------------
if (($(ist 'yandex'))); then
  sudo sed -i 's/stable %U.*/stable %U --disk-cache-dir=\/dev\/null/g' /usr/share/applications/yandex-browser.desktop
  sudo sed -i 's/stable --incognito.*/stable --incognito --disk-cache-dir=\/dev\/null/g' /usr/share/applications/yandex-browser.desktop
  sudo sed -i 's/stable$/stable --disk-cache-dir=\/dev\/null/g' /usr/share/applications/yandex-browser.desktop
  sudo rm -f /etc/xdg/autostart/yandex-browser_user_setup.desktop # что-то добавил странное для всех пользователей в автозагрузку
fi

#-----------------------------------------------------------------------
# Ярлыки / значки / иконки запуска приложений
#-----------------------------------------------------------------------
# Значки запуска придожений /usr/share/applications/
# Значки пользователя ~/.local/share/applications/
# Значки возле пуска  ~/.local/share/plasma_icons/
# Значки в избранном ~/.config/kactivitymanagerd-statsrc
#-----------------------------------------------------------------------
((PHINDEX++))
IDX=$PHINDEX
plasmaicon(){
  local N=${1-} V=${2-}
  echo -e "$V" > ~/.local/share/plasma_icons/$N.desktop
  chmod +x ~/.local/share/plasma_icons/$N.desktop
  kwriteconfig5 --file plasma-org.kde.plasma.desktop-appletsrc --group Containments --group 2 --group Applets --group $IDX --key immutability 1
  kwriteconfig5 --file plasma-org.kde.plasma.desktop-appletsrc --group Containments --group 2 --group Applets --group $IDX --key plugin org.kde.plasma.icon
  kwriteconfig5 --file plasma-org.kde.plasma.desktop-appletsrc --group Containments --group 2 --group Applets --group $IDX --group Configuration --key localPath /home/$USER/.local/share/plasma_icons/$N.desktop
  kwriteconfig5 --file plasma-org.kde.plasma.desktop-appletsrc --group Containments --group 2 --group Applets --group $IDX --group Configuration --key url file:///home/$USER/.local/share/plasma_icons/$N.desktop
  ((IDX++))
}
usricon(){
  local N=${1-} V=${2-} S=${3-}
  if [ -n "$S" ]; then
    echo -e "$S" | sudo tee /usr/bin/$N.sh > /dev/null
    sudo chmod +x /usr/bin/$N.sh
  fi
  echo -e "$V" | sudo tee /usr/share/applications/$N.desktop > /dev/null
  sudo chmod +x /usr/share/applications/$N.desktop
}

#-----------------------------------------------------------------------
# Значки в избранное не добавить, в базу пишет.. Сделаю зачистку.
#-----------------------------------------------------------------------
# sed -i 's/ordering.*/ordering=applications:filezilla.desktop,applications:xamppstart.desktop,applications:org.kde.kdiff3.desktop,applications:libreoffice-writer.desktop,applications:org.kde.ktorrent.desktop,applications:Mailspring.desktop,applications:scrkrita3.desktop/g' ~/.config/kactivitymanagerd-statsrc
echo '' > ~/.config/kactivitymanagerd-statsrc
rm -rf ~/.local/share/kactivitymanagerd/

#-----------------------------------------------------------------------
# Добавляем значки запуска в меню
#-----------------------------------------------------------------------
if (($(ist 'krita'))) && [[ "$SCR" != "0" ]]; then
  # Снимок экрана в файл и открыть в Krita
  usricon 'scrkrita' '[Desktop Entry]\nType=Application\nName=ScreenToKrita\nComment=Скриншот в Krita\nExec=/usr/bin/scrkrita.sh "'$SCR'"\nIcon=spectacle\nCategories=Graphics' '#!/bin/bash\nF=${1-/tmp/0.png}\nrm -f $F\n/usr/bin/scrot $F\n/usr/bin/krita $F'
  # Снимок экрана с задержкой в 3 сек. (2 1 0 снимок) в файл и открыть в Krita
  usricon 'scrkrita3' '[Desktop Entry]\nType=Application\nName=ScreenToKrita 3\nComment=Скриншот в Krita с задержкой в 3 сек.\nExec=/usr/bin/scrkrita3.sh "'$SCR'"\nIcon=spectacle\nCategories=Graphics' '#!/bin/bash\nF=${1-/tmp/0.png}\nrm -f $F\n/usr/bin/scrot -d 2 $F\n/usr/bin/krita $F'
fi
#-----------------------------------------------------------------------
# Добавляем значки запуска рядом с пуском
#-----------------------------------------------------------------------
# plasmaicon 'netbeans' '[Desktop Entry]\nEncoding=UTF-8\nName=NetBeans\nExec=/usr/bin/netbeans\nIcon=apache-netbeans\nCategories=Development;Java;IDE\nVersion=1.0\nType=Application\nTerminal=false\nSmartupWMClass=Apache NetBeans IDE 20'
if (($(ist 'iron'))); then
  plasmaicon 'iron' '[Desktop Entry]\nName=SRWare Iron\nComment=SRWare Iron-Browser\nExec=/usr/share/iron/chrome-wrapper\nIcon=iron_product_logo\nTerminal=false\nType=Application\nCategories=Network;WebBrowser;\nStartupNotify=false\nMimeType=text/html;text/xml;application/xhtml_xml;image/webp;x-scheme-handler/http;x-scheme-handler/https;x-scheme-handler/ftp;'
fi
if (($(ist 'librewolf'))); then
  plasmaicon 'librewolf' '[Desktop Entry]\nType=Application\nName=LibreWolf\nComment=Web Browser\nStartupNotify=true\nTerminal=false\nType=Application\nMimeType=application/json;application/pdf;application/rdf+xml;application/rss+xml;application/xhtml+xml;application/xhtml_xml;application/xml;image/gif;image/jpeg;image/png;image/webp;text/html;text/xml;x-scheme-handler/http;x-scheme-handler/https;\nComment=LibreWolf Browser\nCategories=Network;WebBrowser;Security;\nStartupWMClass=librewolf-default\nExec=/usr/share/librewolf/librewolf %u\nIcon=librewolf\nActions=new-window;new-private-window;safe-mode;preferences;\n[Desktop Action new-window]\nName=New Window\nExec=/usr/share/librewolf/librewolf\n[Desktop Action new-private-window]\nName=New Private Window\nExec=/usr/share/librewolf/librewolf --private-window %u\n[Desktop Action safe-mode]\nName=Start in Safe Mode\nExec=/usr/share/librewolf/librewolf --safe-mode\n[Desktop Action preferences]\nName=Show Preferences\nExec=/usr/share/librewolf/librewolf --preferences'
fi
if [[ "$NOTES" != "0" ]]; then plasmaicon 'notes' '[Desktop Entry]\nType=Application\nName=Notes\nExec=/usr/bin/geany "'$NOTES'"\nIcon=x-office-document'; fi
if [[ "$DIR" != "0" ]]; then plasmaicon 'dir' '[Desktop Entry]\nName=Directory\nIcon=inode-directory\nType=Link\nURL=file://'$DIR; fi
if (($(ist 'krita'))) && [[ "$SCR" != "0" ]];  then plasmaicon 'scrkrita' '[Desktop Entry]\nType=Application\nName=ScreenToKrita\nComment=Скриншот в Krita\nExec=/usr/bin/scrkrita.sh "'$SCR'"\nIcon=spectacle\nCategories=Graphics'; fi

#-----------------------------------------------------------------------
# Расставляем в каком порядке должны идти апплеты (виджеты) в панели
#-----------------------------------------------------------------------
PORDER=''
if [ "$IDX" -ne "$PHINDEX" ]; then
  for ((I=PHINDEX; I<IDX; I++)); do PORDER+=$I';'; done
fi
if (($PSEPARATOR > 0)); then PSEPARATOR+=';'; else PSEPARATOR=''; fi
#      '3;         значки;21;             6;         5;       4;       7;             20'
PORDER=$PKICKOFF';'$PORDER$PSHOWDESKTOP';'$PSEPARATOR$PTASK';'$PAGER';'$PSYSTEMTRAY';'$PDIGITALCLOCK
kwriteconfig5 --file plasma-org.kde.plasma.desktop-appletsrc --group Containments --group 2 --group General --key AppletOrder $PORDER

#-----------------------------------------------------------------------
# Настраиваем xbindkeys - глобальные горячие клавиши   then cp -v ./.xbindkeysrc ~/; fi
#-----------------------------------------------------------------------
if (($(ist 'xbindkeys'))); then
  if ! [ -e  ~/.xbindkeysrc ]; then
    wget -qP ~/ https://fsen.ru/inc/doc/linux/soft/.xbindkeysrc;
    EE=/usr/share/applications/xvkbd.desktop
    if [ -e "$EE" ]; then
      F=$(cat $EE | grep -c 'Icon') # Количество вхождений
      if [ "$F" -eq 0 ]; then echo 'Icon=input-keyboard' | sudo tee -a /usr/share/applications/xvkbd.desktop > /dev/null; fi
    fi
  fi
fi
if (($(ist 'xbindkeys-config'))); then usricon 'xbindkeys-config' '[Desktop Entry]\nType=Application\nName=xbindkeys-config\nComment=Настройка глобальных горячих клавиш\nExec=/usr/bin/xbindkeys-config\nIcon=preferences-desktop-keyboard\nCategories=Settings'; fi
#-----------------------------------------------------------------------
# Устраняем повторы в разных категориях в меню (Utility - Служебные)
#-----------------------------------------------------------------------
sudo sed -i 's/Categories.*/Categories=Office/g' /usr/share/applications/org.kde.kate.desktop
sudo sed -i 's/Categories.*/Categories=Office/g' /usr/share/applications/org.kde.kwrite.desktop
sudo sed -i 's/Categories.*/Categories=Office/g' /usr/share/applications/org.kde.okular.desktop
sudo sed -i 's/Categories.*/Categories=Development/g' /usr/share/applications/geany.desktop
sudo sed -i 's/Categories.*/Categories=Utility/g' /usr/share/applications/xvkbd.desktop
sudo sed -i 's/Categories.*/Categories=Utility/g' /usr/share/applications/org.kde.k3b.desktop
# sudo sed -i 's/Categories.*/Categories=Game/g' /usr/lib/steam/steam.desktop

#-----------------------------------------------------------------------
# Настраиваем приложения
#-----------------------------------------------------------------------
rm -f /tmp/tunesoft.sh && wget -qP /tmp https://fsen.ru/inc/doc/linux/tunesoft.sh && chmod +x /tmp/tunesoft.sh && /tmp/tunesoft.sh

#-----------------------------------------------------------------------
# Настраиваем оформление KDE
#-----------------------------------------------------------------------
if (($(ist "oxygen-icon-theme"))); then
  kwriteconfig5 --file kdeglobals --group KDE --key widgetStyle Oxygen            # Оформление приложений
  kwriteconfig5 --file kdeglobals --group Icons --key Theme oxygen                # Значки
fi

#-----------------------------------------------------------------------
# Скрипт для управления звуковой системой                               # sudo cp -v ./fsesound /usr/bin/
#-----------------------------------------------------------------------
if ! [ -e /usr/bin/fsesound ]; then
  u=https://fsen.ru/inc/doc/linux/;l=/usr/bin/;n=fsesound;sudo rm -f $l$n*;sudo wget -qP $l $u$n $u$n'f';sudo chmod +x $l$n*
  fsesound upmix 1
  if [[ "$VOLUME" != "0" ]]; then fsesound icon start $VOLUME; fi
  fsesound icon soundstereo 'Sound to Stereo' 'set ss "all"' #"HD Audio"
  fsesound icon sound51 'Sound to Surround 5.1' 'set 51s "all"'
fi
#-----------------------------------------------------------------------
# Включаем и настраиваем эквалайзер, добавим в автозагрузку с фоновым запуском
#-----------------------------------------------------------------------
if (($(ist 'easyeffects'))); then
  if [ -e /var/lib/flatpak/app/com.github.wwmm.easyeffects/ ]; then
    nohup flatpak run com.github.wwmm.easyeffects > /dev/null 2>&1 &
    sleep 10
    flatpak kill com.github.wwmm.easyeffects
    killall -15 easyeffects
    sleep 5

    sudo apt install -y unzip
    EE=~/.var/app/com.github.wwmm.easyeffects/config/easyeffects/
    mkdir -p $EE
    wget -qP /tmp --show-progress https://fsen.ru/inc/doc/linux/soft/eepresets.zip
    unzip -uq /tmp/eepresets.zip -d $EE
    rm -f /tmp/eepresets.zip

    #nohup /usr/bin/flatpak run --command=easyeffects com.github.wwmm.easyeffects --gapplication-service > /dev/null 2>&1 &
    # nohup flatpak run com.github.wwmm.easyeffects > /dev/null 2>&1 &
    #sleep 10

    L=$(pactl info | grep '^Server Name');
    if ! [[ $L =~ 'PipeWire' ]]; then # Server Name: pulseaudio
      sudo add-apt-repository -y ppa:pipewire-debian/pipewire-upstream
      sudo apt update
      sudo apt upgrade -y
      sudo apt install -y pipewire
      sudo apt install -y gstreamer1.0-pipewire
      sudo apt install -y libspa-0.2-bluetooth
      sudo apt install -y libspa-0.2-jack
      # Disabling PulseAudio
      systemctl --user --now disable pulseaudio.{socket,service}
      systemctl --user mask pulseaudio # Created symlink /home/ac/.config/systemd/user/pulseaudio.service → /dev/null
      # Enabling PipeWire
      sudo cp -vRa /usr/share/pipewire /etc/
      systemctl --user --now enable pipewire{,-pulse}.{socket,service} filter-chain.service
      # pactl info | grep '^Server Name' == Server Name: PulseAudio (on PipeWire 1.0.3)

    fi
    fsesound setpreset 'fsen.ru Sony MDR-EX15LP' 'all' 'analog-stereo' 'analog-output-lineout'
    fsesound icon soundsony 'Sound Sony MDR-EX15LP' "setpreset 'fsen.ru Sony MDR-EX15LP' 'all' 'analog-stereo' 'analog-output-lineout'"
    fsesound icon soundsennheiser 'Sound Sennheiser HD 280 PRO' "setpreset 'fsen.ru Sennheiser HD 280 PRO' 'all' 'analog-stereo' 'analog-output-lineout'"
    fsesound icon soundaxelvox 'Sound Axelvox HD272' "setpreset 'fsen.ru Axelvox HD272' 'all' 'analog-stereo' 'analog-output-lineout'"
    fsesound icon starteasyeffects 1
  fi
fi

#-----------------------------------------------------------------------
# Чистка
#-----------------------------------------------------------------------
# Удаление ярлыков из меню
sudo rm -vf /usr/share/applications/info.desktop /usr/share/applications/org.kde.khelpcenter.desktop /usr/share/applications/org.kde.plasma-welcome.desktop /usr/share/applications/smtube.desktop /usr/share/applications/mpv.desktop /usr/share/applications/org.kde.kuserfeedback-console.desktop
# /usr/share/applications/org.kde.pimsettingexporter.desktop /usr/share/applications/openjdk-*-policytool.desktop
sudo apt remove -y firefox
# Удаление программ
if (($(ist 'remove-firefox'))); then killall -15 firefox; sudo apt remove -y firefox; sudo snap remove firefox; fi
# sudo apt purge -y mpv # связан с SMPlayer нельзя удалять
sudo apt-get remove -y imagemagick*
#-----------------------------------------------------------------------
# IBus Panel
#-----------------------------------------------------------------------
sudo apt remove -y ibus
sudo apt remove -y ibus-gtk
sudo apt remove -y ibus-gtk3
sudo apt remove -y ibus-lang
sudo apt remove -y ibus-m17n

#-----------------------------------------------------------------------
sudo apt clean
sudo apt autoremove -y
rm -vf ~/nohup.out
#-----------------------------------------------------------------------
# Сломанные пакеты
# sudo apt update --fix-missing
# sudo apt install -f
# sudo apt clean

# sudo apt autoremove -y
# или
# sudo dpkg --configure -a
# sudo dpkg --remove -force --force-remove-reinstreq имя_пакета

#-----------------------------------------------------------------------
# Разрешаем порты для DC и Torrent, и включаем фаерволл
#-----------------------------------------------------------------------
sudo ufw allow 3000 && sudo ufw allow 3001 && sudo ufw allow 3002 && sudo ufw allow 3003
sudo ufw enable

#-----------------------------------------------------------------------
# Включаем бумажник KDE - иначе mailspring уходит в отказ.. + netbeans не сохраняет пароли соединений, а раньше сохранял..
#-----------------------------------------------------------------------
kwriteconfig5 --file kwalletrc --group Wallet --key Enabled --type bool true

#----------------------------------------------------------------------- mailspring уходит в отказ.. + netbeans не сохраняет пароли соединений, а раньше сохранял..
# Перезапуск оболочки KDE
#-----------------------------------------------------------------------
rm -f /tmp/kdeup.sh; wget -qP /tmp https://fsen.ru/inc/doc/linux/kdeup.sh; chmod +x /tmp/kdeup.sh; /tmp/kdeup.sh

LE='------------------------------------------------------------------------------------------------------'
LEN=102
echo $LE
echo '--------------------------- УСТАНОВКА ЗАВЕРШЕНА! Необходима перезагрузка. ----------------------------'
echo '----------------- Осталось: Примонтировать диск к директории /a/; Настроить программы ----------------'
echo $LE
str_pad_repeat(){
  local S=${1-} L=${2-0} R=''
  while ((${#R} < L)); do R+="$S"; done
  echo "${R:0:$L}"
}
str_pad(){ # input, pad_length, pad_string, pad_type[0=STR_PAD_LEFT, 1=STR_PAD_RIGHT, 2=STR_PAD_BOTH, 3=По центру добавляет только слева]
  local S=${1-} L=${2-0} D=${3- } T=${4-1} N=0 P=''
  N=$((L - ${#S}))
  if ((N > 0)); then P="$(str_pad_repeat "$D" "$N")"
    if ((T == 0)); then S="$P$S"
    elif ((T == 1)); then S+="$P"
    elif ((T > 1)); then
      ((N % 2 != 0)) && N=$(ceil "$N.9") # $((9 / 2)) = 4
      N=$((N / 2)); P="${P:0:$N}"
      ((T == 3)) && S="$P$S" || S="$P$S$P";
      S="${S:0:$L}"
    fi
  fi; echo "$S"
}
waitkey(){
  local A=${1-'Введите номер пункта и нажмите enter: '} R=''
  read -p $'\n'"$LE"$'\n\n'"$(str_pad "$A" $LEN ' ' 3)" R
  echo "$R"
}
B='\033[1;30m'
N='\033[0m'
echo -e "\n\n$LE\n\n$B 0) Выйти (Ctrl+C)$N\n$LS$B 1) Перезагрузить компьютер $N";
while :; do R=$(waitkey)
  if [[ $R == 0 ]]; then exit 0
  elif [[ $R == 1 ]]; then sudo reboot; break; fi
done
