#!/bin/bash
# Fast Site Engine. Copyright © AC (acwed@ya.ru), 2004-2024. All rights reserved. 2-clause BSD license.
# Установщик и настройщик программ и оболочки для KDE Neon User Edition (основан на Ubuntu 22.04 LTS (Jammy Jellyfish) окончание поддержки 04.2027)
# https://fsen.ru/linux/tune  DISTR='jammy' / tune.sh служебный скрипт, вызывается в процесе установки из setup.sh
# rm -f /tmp/tune.sh && wget -qP /tmp https://fsen.ru/inc/doc/linux/tune.sh && chmod +x /tmp/tune.sh && /tmp/tune.sh

#-----------------------------------------------------------------------

if [[ -z $(env | grep '^VOLUME=') ]]; then
  echo '------------------------------------------------------------------------------------------------------'
  echo '------------------------ НАСТРОЙКА ПРЕРВАНА! Вызов не из установщика setup.sh. -----------------------'
  echo '------------------------------------------------------------------------------------------------------'
  exit 1;
fi

#-----------------------------------------------------------------------
# Создаём директории
#----------------------------------------------------------------------- /etc/xdg/autostart/
mkdir -p ~/.config/autostart/
mkdir -p ~/.local/share/plasma_icons/
sudo mkdir -p /etc/apt/keyrings/

#-----------------------------------------------------------------------
# Разгоняем производительность файловой системы
#-----------------------------------------------------------------------
sudo sed -i -e 's/remount-ro/remount-ro,noatime,nodiratime/g' -e 's/defaults/defaults,noatime,nodiratime/g' -e 's/defaults,defaults/defaults/g' -e 's/noatime,noatime/noatime/g' -e 's/nodiratime,nodiratime/nodiratime/g' -e 's/noatime,nodiratime,noatime,nodiratime/noatime,nodiratime/g' /etc/fstab
# sudo sed -i -e 's/noatime,nodiratime,noatime,nodiratime/noatime,nodiratime/g' /etc/fstab

#-----------------------------------------------------------------------
# Ограничиваем логи
#-----------------------------------------------------------------------
sudo journalctl --rotate
sudo journalctl --vacuum-size=100M
sudo sed -i 's/^.*SystemMaxUse.*$/SystemMaxUse=100M/g' /etc/systemd/journald.conf
sudo systemctl daemon-reload

#-----------------------------------------------------------------------
# Снимаем ограничение скорости в 100Мбит, разрешив согласование с роутером
#-----------------------------------------------------------------------
# nmcli con show "Wired connection 1"  # nmcli con show "Проводное соединение 1"  # Посмотреть настройки
# //Изменить настройки  100 full no   //[true, yes, on] или [false, no, off]. nmcli help  # /etc/NetworkManager/system-connections
nmcli connection modify 'Wired connection 1' 802-3-ethernet.speed 0
nmcli connection modify 'Wired connection 1' 802-3-ethernet.duplex ''
nmcli connection modify 'Wired connection 1' 802-3-ethernet.auto-negotiate 'yes'
# В разных дистрибутивах по разному, либо первое, либо второе сработает
nmcli connection modify 'Проводное соединение 1' 802-3-ethernet.speed 0
nmcli connection modify 'Проводное соединение 1' 802-3-ethernet.duplex ''
nmcli connection modify 'Проводное соединение 1' 802-3-ethernet.auto-negotiate 'yes'

#-----------------------------------------------------------------------
# Открепим приложения с панели задач KDE
#-----------------------------------------------------------------------
kwriteconfig5 --file plasma-org.kde.plasma.desktop-appletsrc --group Containments --group $PANEL --group Applets --group $PTASK --group Configuration --group General --key launchers ''
# [Containments][2][Applets][5][Configuration][General]
# launchers=file:///usr/share/applications/discord.desktop

#-----------------------------------------------------------------------# см. в ~/.config/
# Отключим всплывающее уведомление - Соединение установлено
#-----------------------------------------------------------------------
kwriteconfig5 --file networkmanagement.notifyrc --group Event/ConnectionActivated --key Action ''

#-----------------------------------------------------------------------
# Изменим время блокировки экрана
#-----------------------------------------------------------------------
# Автоматически блокировать экран: При отсутствии активности в течении: 25 минут
kwriteconfig5 --file kscreenlockerrc --group Daemon --key Timeout 15
# Разблокировать без пароля в течении: 58 секунд
kwriteconfig5 --file kscreenlockerrc --group Daemon --key LockGrace 58
# Энергосбережение монитора - Выключить через 16 мин
kwriteconfig5 --file powermanagementprofilesrc --group AC --group DPMSControl --key idleTime 960
# Приостановка сеанса: Отключаем
kwriteconfig5 --file powermanagementprofilesrc --group AC --group SuspendSession --key idleTime --delete
kwriteconfig5 --file powermanagementprofilesrc --group AC --group SuspendSession --key suspendThenHibernate --delete
kwriteconfig5 --file powermanagementprofilesrc --group AC --group SuspendSession --key suspendType --delete
# При нажатии кнопки питания: Выключить компьютер
kwriteconfig5 --file powermanagementprofilesrc --group AC --group HandleButtonEvents --key powerButtonAction 8

## kreadconfig5 --file plasmashellrc --group PlasmaViews --group 'Panel 2' --group Defaults --key thickness
#-----------------------------------------------------------------------
# Настроим панель задач PlasmaShell
#-----------------------------------------------------------------------
# Значки поменьше в Dolphin в точках входа
kwriteconfig5 --file plasmashellrc --group 'KFileDialog Settings' --group Defaults --key detailViewIconSize 16
# Высота панели 36 вместо 44
kwriteconfig5 --file plasmashellrc --group PlasmaViews --group 'Panel 2' --group Defaults --key thickness 36
kwriteconfig5 --file plasmashellrc --group PlasmaViews --group 'Panel 2' --group Horizontal1920 --key thickness 36

#-----------------------------------------------------------------------
# Заменим виджет Панель задач только значки на классический вариант     # [Containments][2(PANEL)][Applets][5(PTASK)]
#-----------------------------------------------------------------------
# kwriteconfig5 --file plasma-org.kde.plasma.desktop-appletsrc --group Containments --group $PANEL --group Applets --group $PTASK --key immutability 1
kwriteconfig5 --file plasma-org.kde.plasma.desktop-appletsrc --group Containments --group $PANEL --group Applets --group $PTASK --key plugin org.kde.plasma.taskmanager # org.kde.plasma.icontasks
# kwriteconfig5 --file plasma-org.kde.plasma.desktop-appletsrc --group Containments --group $PANEL --group Applets --group $PTASK --group Configuration --key PreloadWeight 42
# kwriteconfig5 --file plasma-org.kde.plasma.desktop-appletsrc --group Containments --group $PANEL --group Applets --group $PTASK --group Configuration --group ConfigDialog --key DialogHeight 540
# kwriteconfig5 --file plasma-org.kde.plasma.desktop-appletsrc --group Containments --group $PANEL --group Applets --group $PTASK --group Configuration --group ConfigDialog --key DialogWidth 884

#-----------------------------------------------------------------------
# Настроим виджет Панель задач
#-----------------------------------------------------------------------
# Выключаем - Показывать миниатюру окна при наведении указателя мыши на элемент в панели задач
kwriteconfig5 --file plasma-org.kde.plasma.desktop-appletsrc --group Containments --group $PANEL --group Applets --group $PTASK --group Configuration --group General --key showToolTips --type bool false
# Максимальное число строк 2
kwriteconfig5 --file plasma-org.kde.plasma.desktop-appletsrc --group Containments --group $PANEL --group Applets --group $PTASK --group Configuration --group General --key maxStripes 2

# Вкладка Поведение:
# Не группировать
kwriteconfig5 --file plasma-org.kde.plasma.desktop-appletsrc --group Containments --group $PANEL --group Applets --group $PTASK --group Configuration --group General --key groupingStrategy 0
# Сортировать вручную
kwriteconfig5 --file plasma-org.kde.plasma.desktop-appletsrc --group Containments --group $PANEL --group Applets --group $PTASK --group Configuration --group General --key sortingStrategy 1
# Показывать приложения: С текущего экрана
kwriteconfig5 --file plasma-org.kde.plasma.desktop-appletsrc --group Containments --group $PANEL --group Applets --group $PTASK --group Configuration --group General --key showOnlyCurrentDesktop --type bool true
# Показывать приложения: С текущего рабочего стола
kwriteconfig5 --file plasma-org.kde.plasma.desktop-appletsrc --group Containments --group $PANEL --group Applets --group $PTASK --group Configuration --group General --key showOnlyCurrentScreen --type bool true

#-----------------------------------------------------------------------
# Рабочие столы
#-----------------------------------------------------------------------
kwriteconfig5 --file kwinrc --group Desktops --key Number 4 # Количество рабочих столов: 4
kwriteconfig5 --file kwinrc --group Desktops --key Rows 1 # Количество рядов: 1
kwriteconfig5 --file kwinrc --group Plugins --key slideEnabled --type bool false # Без анимации при переключении

#-----------------------------------------------------------------------
# Настроим виджет Громкость (KDE6 Neon)
#-----------------------------------------------------------------------
# Увеличить максимальную громкость 150%
kwriteconfig5 --file plasmaparc --group General --key RaiseMaximumVolume --type bool true
# Шаг изменения громкости: 3%
kwriteconfig5 --file plasmaparc --group General --key VolumeStep 3
# Воспроизводить звук при регулировке устройств: Громкость звука
kwriteconfig5 --file plasmaparc --group General --key AudioFeedback --type bool false
# Показывать уведомления при регулировке устройств: Громкость звука
kwriteconfig5 --file plasmaparc --group General --key VolumeOsd --type bool false

# В Kubuntu это здесь [Containments][6(SYSTEMTRAY)][Applets][12].      # [Containments][8][Applets][9][Configuration][General]
PVOL=9 # org.kde.plasma.volume
for ((I=0; I<40; I++)); do
  V=$(kreadconfig5 --file plasma-org.kde.plasma.desktop-appletsrc --group Containments --group $SYSTEMTRAY --group Applets --group $I --key plugin)
  if [ -n "$V" ] && [[ $V =~ 'volume' ]]; then PVOL=$I; break; fi
done
kwriteconfig5 --file plasma-org.kde.plasma.desktop-appletsrc --group Containments --group $SYSTEMTRAY --group Applets --group $PVOL --group Configuration --group General --key micOsd --type bool false
kwriteconfig5 --file plasma-org.kde.plasma.desktop-appletsrc --group Containments --group $SYSTEMTRAY --group Applets --group $PVOL --group Configuration --group General --key muteOsd --type bool false
kwriteconfig5 --file plasma-org.kde.plasma.desktop-appletsrc --group Containments --group $SYSTEMTRAY --group Applets --group $PVOL --group Configuration --group General --key outputChangeOsd --type bool false
kwriteconfig5 --file plasma-org.kde.plasma.desktop-appletsrc --group Containments --group $SYSTEMTRAY --group Applets --group $PVOL --group Configuration --group General --key volumeFeedback --type bool false
kwriteconfig5 --file plasma-org.kde.plasma.desktop-appletsrc --group Containments --group $SYSTEMTRAY --group Applets --group $PVOL --group Configuration --group General --key volumeStep 3
# В более ранних: kwriteconfig5 --file plasmarc --group OSD --key Enabled --type bool false

#-----------------------------------------------------------------------
# Прячем значки в Системном лотке  # SYSTEMTRAY=8  В Kubuntu systemtray под индексом 7
#-----------------------------------------------------------------------
kwriteconfig5 --file plasma-org.kde.plasma.desktop-appletsrc --group Containments --group $SYSTEMTRAY --group General --key hiddenItems 'org.kde.plasma.clipboard,org.kde.plasma.vault,org.kde.plasma.networkmanagement,org.kde.discovernotifier,qasmixer,Plasma_microphone,org.kde.plasma.notifications,Уведомления центра программ Discover_org.kde.DiscoverNotifier,org.kde.plasma.keyboardindicator'

#-----------------------------------------------------------------------
# Настраиваем часы   # [Containments][2(PANEL)][Applets][20(PDIGITALCLOCK)]  В Kubuntu часы под индексом 8
#-----------------------------------------------------------------------
# Показывать дату, в KDE Neon включено по умолчанию
# kwriteconfig5 --file plasma-org.kde.plasma.desktop-appletsrc --group Containments --group $PANEL --group Applets --group $PDIGITALCLOCK --group Configuration --group Appearance --key showDate --type bool true

# Формат даты: Формат ISO
kwriteconfig5 --file plasma-org.kde.plasma.desktop-appletsrc --group Containments --group $PANEL --group Applets --group $PDIGITALCLOCK --group Configuration --group Appearance --key dateFormat isoDate

# Включаем: Праздники (Holidays)
kwriteconfig5 --file plasma-org.kde.plasma.desktop-appletsrc --group Containments --group $PANEL --group Applets --group $PDIGITALCLOCK --group Configuration --group Appearance --key enabledCalendarPlugins '/usr/lib/x86_64-linux-gnu/qt5/plugins/plasmacalendarplugins/holidaysevents.so'

# Отображать праздники региона ru
kwriteconfig5 --file plasma_calendar_holiday_regions --group General --key selectedRegions ru_ru

#-----------------------------------------------------------------------
# Настраиваем оформление KDE
#-----------------------------------------------------------------------
kwriteconfig5 --file plasmarc --group Theme --key name breeze-dark              # Оформление рабочего стола

if [ -e /usr/share/color-schemes/BreezeClassic.colors ]; then
kwriteconfig5 --file kdeglobals --group General --key ColorScheme BreezeClassic # Цвета Breeze, классический вариант
else
kwriteconfig5 --file kdeglobals --group General --key ColorScheme Breeze # В старых оболочках KDE
fi
# kwriteconfig5 --file ./gtk-3.0/settings.ini --group Settings --key 'gtk-application-prefer-dark-theme' 0 # Цвета Breeze
# kwriteconfig5 --file ./gtk-3.0/settings.ini --group Settings --key 'gtk-fallback-icon-theme' gnome
# kwriteconfig5 --file ./gtk-3.0/settings.ini --group Settings --key 'gtk-icon-theme-name' oxygen
# kwriteconfig5 --file ./gtk-4.0/settings.ini --group Settings --key 'gtk-application-prefer-dark-theme' 0
# kwriteconfig5 --file ./gtk-4.0/settings.ini --group Settings --key 'gtk-fallback-icon-theme' gnome
# kwriteconfig5 --file ./gtk-4.0/settings.ini --group Settings --key 'gtk-icon-theme-name' oxygen

#-----------------------------------------------------------------------
# Отключить hotcorner - действие если курсор в правом углу экрана, появления всех окон
#-----------------------------------------------------------------------
# kwriteconfig5 --file kwinrc --group ElectricBorders --key TopRight None

#-----------------------------------------------------------------------
# Отключим экран завершения работы
#-----------------------------------------------------------------------
kwriteconfig5 --file ksmserverrc --group General --key confirmLogout --type bool false

#-----------------------------------------------------------------------
# Отключим службу поиска файлов (это источник тормозов в KDE)
#-----------------------------------------------------------------------
kwriteconfig5 --file baloofilerc --group 'Basic Settings' --key Indexing-Enabled --type bool false

#-----------------------------------------------------------------------
# Изменим уведомления
#-----------------------------------------------------------------------
kwriteconfig5 --file plasmanotifyrc --group Notifications --key LowPriorityPopups --type bool false
kwriteconfig5 --file plasmanotifyrc --group Notifications --key PopupTimeout 3000

#-----------------------------------------------------------------------
# Дополнительное переключения языка на правый Alt
#-----------------------------------------------------------------------
kwriteconfig5 --file kxkbrc --group Layout --key Options grp:alt_shift_toggle,grp:toggle,grp_led:scroll

# Ушло в прошлое, теперь по умолчанию с 1 щелчка
#(Оборудование) → Устройства ввода →  Мышь → Одинарный щелчок для открытия файлов и каталогов
kwriteconfig5 --file kdeglobals --group KDE --key SingleClick --type bool true

#-----------------------------------------------------------------------
# Отключим создание миниатюр окон
#-----------------------------------------------------------------------
kwriteconfig5 --file kwinrc --group Compositing --key HiddenPreviews 4

#-----------------------------------------------------------------------
# Автоматически подключать внешние носители
#-----------------------------------------------------------------------
kwriteconfig5 --file kded5rc --group Module-device_automounter --key autoload --type bool true
kwriteconfig5 --file kded_device_automounterrc --group General --key AutomountEnabled --type bool true
kwriteconfig5 --file kded_device_automounterrc --group General --key AutomountOnLogin --type bool true
kwriteconfig5 --file kded_device_automounterrc --group General --key AutomountOnPlugin --type bool true

#-----------------------------------------------------------------------
# Частота обновления пакетов - еженедельно
#-----------------------------------------------------------------------
kwriteconfig5 --file PlasmaDiscoverUpdates --group Global --key RequiredNotificationInterval 604800
# Отключаем: Использовать отложенные обновления
kwriteconfig5 --file discoverrc --group Software --key UseOfflineUpdates --type bool false

#-----------------------------------------------------------------------
# Настраиваем Dolphin
#-----------------------------------------------------------------------
# Управление - Настроить Dolphin...
# Снимаем галку: Открывать новые папки во вкладках
kwriteconfig5 --file dolphinrc --group General --key OpenExternallyCalledFolderInNewTab --type bool false
# Ставим галку: Полный путь в строке адреса
kwriteconfig5 --file dolphinrc --group General --key ShowFullPath --type bool true
# Управление - Показывать скрытые файлы
kwriteconfig5 --file dolphinrc --group FoldersPanel --key HiddenFilesShown --type bool true
# Главное - Использовать индивидуальные свойства для каждой папки
kwriteconfig5 --file dolphinrc --group General --key GlobalViewProps --type bool false
# Начальное состояние - Окрывать при запуске - Папки и вкладки - Выключаем запоминание закладок.
kwriteconfig5 --file dolphinrc --group General --key RememberOpenedTabs --type bool false

#-----------------------------------------------------------------------
# Отключаем эффекты
#-----------------------------------------------------------------------
# Масштабирование
kwriteconfig5 --file kwinrc --group Plugins --key kwin4_effect_scaleEnabled --type bool false
# Разбрасывание окон в стороны
kwriteconfig5 --file kwinrc --group Plugins --key kwin4_effect_windowapertureEnabled --type bool false
# Контрастность фона
kwriteconfig5 --file kwinrc --group Plugins --key contrastEnabled --type bool false
# Край экрана
kwriteconfig5 --file kwinrc --group Plugins --key screenedgeEnabled --type bool false
# Анимация всплывающих окон
kwriteconfig5 --file kwinrc --group Plugins --key slidingpopupsEnabled --type bool false
# Анимация преобразования всплывающих окон
kwriteconfig5 --file kwinrc --group Plugins --key kwin4_effect_morphingpopupsEnabled --type bool false
# Входв систему
kwriteconfig5 --file kwinrc --group Plugins --key kwin4_effect_loginEnabled --type bool false
# Завершение работы
kwriteconfig5 --file kwinrc --group Plugins --key kwin4_effect_logoutEnabled --type bool false
# Максимизировать
kwriteconfig5 --file kwinrc --group Plugins --key kwin4_effect_maximizeEnabled --type bool false
# Обесцвечивание зависших приложений
kwriteconfig5 --file kwinrc --group Plugins --key kwin4_effect_frozenappEnabled --type bool false
# Полноэкранный режим
kwriteconfig5 --file kwinrc --group Plugins --key kwin4_effect_fullscreenEnabled --type bool false
# Размытие
kwriteconfig5 --file kwinrc --group Plugins --key blurEnabled --type bool false
# Растворяющиеся всплывающие окна
kwriteconfig5 --file kwinrc --group Plugins --key kwin4_effect_fadingpopupsEnabled --type bool false
# Сжатие при сворачивании окна
kwriteconfig5 --file kwinrc --group Plugins --key kwin4_effect_squashEnabled --type bool false
# Масштаб
kwriteconfig5 --file kwinrc --group Plugins --key zoomEnabled --type bool false
# Все окна
kwriteconfig5 --file kwinrc --group Plugins --key presentwindowsEnabled --type bool false
# Все рабочие столы
kwriteconfig5 --file kwinrc --group Plugins --key desktopgridEnabled --type bool false
# Обзор
kwriteconfig5 --file kwinrc --group Plugins --key overviewEnabled --type bool false
# Затемнение основного окна
kwriteconfig5 --file kwinrc --group Plugins --key kwin4_effect_dialogparentEnabled --type bool false

echo '------------------------------------------------------------------------------------------------------'
echo '----------------------------------------- Настройка завершена ----------------------------------------'
echo '------------------------------------------------------------------------------------------------------'
